# Generated by Django 3.2.12 on 2022-02-02 16:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("emeis_core", "0006_rename_field_meta_metainfo"),
    ]

    operations = [
        migrations.AlterField(
            model_name="acl",
            name="metainfo",
            field=models.JSONField(default=dict, verbose_name="metainfo"),
        ),
        migrations.AlterField(
            model_name="permission",
            name="metainfo",
            field=models.JSONField(default=dict, verbose_name="metainfo"),
        ),
        migrations.AlterField(
            model_name="role",
            name="metainfo",
            field=models.JSONField(default=dict, verbose_name="metainfo"),
        ),
        migrations.AlterField(
            model_name="scope",
            name="metainfo",
            field=models.JSONField(default=dict, verbose_name="metainfo"),
        ),
        migrations.AlterField(
            model_name="user",
            name="metainfo",
            field=models.JSONField(default=dict, verbose_name="metainfo"),
        ),
    ]
